==> centreon-web-24.04.18.tar.gz: centreon-web-24.04.18/src/Core/ServiceSeverity/Domain/Model/ServiceSeverity.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\ServiceSeverity\Domain\Model;

use Assert\AssertionFailedException;
use Centreon\Domain\Common\Assertion\Assertion;

class ServiceSeverity
{
    public const MAX_NAME_LENGTH = 200,
        MAX_ALIAS_LENGTH = 200,
        MIN_LEVEL_VALUE = -128,
        MAX_LEVEL_VALUE = 127;

    private string $shortName = '';

    private bool $isActivated = true;

    /**
     * @param int $id
     * @param string $name
     * @param string $alias
     * @param int $level
     * @param int $iconId
     *
     * @throws AssertionFailedException
     */
    public function __construct(
        private readonly int $id,
        private string $name,
        private string $alias,
        private int $level,
        private int $iconId
    ) {
        $this->shortName = (new \ReflectionClass($this))->getShortName();

        $this->setName($name);
        $this->setAlias($alias);
        $this->setIconId($iconId);
        $this->setLevel($level);
    }

    /**
     * @return int
     */
    public function getId(): int
    {
        return $this->id;
    }

    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @param string $name
     *
     * @throws \Throwable
     */
    public function setName(string $name): void
    {
        $name = trim($name);

        Assertion::notEmptyString($name, $this->shortName . '::name');
        Assertion::maxLength($name, self::MAX_NAME_LENGTH, $this->shortName . '::name');

        $this->name = $name;
    }

    public function getAlias(): string
    {
        return $this->alias;
    }

    /**
     * @param string $alias
     *
     * @throws \Throwable
     */
    public function setAlias(string $alias): void
    {
        $alias = trim($alias);

        Assertion::notEmptyString($alias, $this->shortName . '::alias');
        Assertion::maxLength($alias, self::MAX_ALIAS_LENGTH, $this->shortName . '::alias');

        $this->alias = $alias;
    }

    public function getLevel(): int
    {
        return $this->level;
    }

    /**
     * @param int $level
     *
     * @throws \Throwable
     */
    public function setLevel(int $level): void
    {
        Assertion::min($level, self::MIN_LEVEL_VALUE, $this->shortName . '::level');
        Assertion::max($level, self::MAX_LEVEL_VALUE, $this->shortName . '::level');

        $this->level = $level;
    }

    public function getIconId(): int
    {
        return $this->iconId;
    }

    /**
     * @param int $iconId
     *
     * @throws \Throwable
     */
    public function setIconId(int $iconId): void
    {
        Assertion::positiveInt($iconId, $this->shortName . '::iconId');

        $this->iconId = $iconId;
    }

    public function isActivated(): bool
    {
        return $this->isActivated;
    }

    public function setActivated(bool $isActivated): void
    {
        $this->isActivated = $isActivated;
    }
}

==> centreon-web-24.10.18.tar.gz: centreon-web-24.10.18/src/Core/ServiceSeverity/Domain/Model/ServiceSeverity.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\ServiceSeverity\Domain\Model;

use Assert\AssertionFailedException;
use Centreon\Domain\Common\Assertion\Assertion;

class ServiceSeverity
{
    public const MAX_NAME_LENGTH = 200;
    public const MAX_ALIAS_LENGTH = 200;
    public const MIN_LEVEL_VALUE = -128;
    public const MAX_LEVEL_VALUE = 127;

    private string $shortName = '';

    private bool $isActivated = true;

    /**
     * @param int $id
     * @param string $name
     * @param string $alias
     * @param int $level
     * @param int $iconId
     *
     * @throws AssertionFailedException
     */
    public function __construct(
        private readonly int $id,
        private string $name,
        private string $alias,
        private int $level,
        private int $iconId
    ) {
        $this->shortName = (new \ReflectionClass($this))->getShortName();

        $this->setName($name);
        $this->setAlias($alias);
        $this->setIconId($iconId);
        $this->setLevel($level);
    }

    /**
     * @return int
     */
    public function getId(): int
    {
        return $this->id;
    }

    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @param string $name
     *
     * @throws \Throwable
     */
    public function setName(string $name): void
    {
        $name = trim($name);

        Assertion::notEmptyString($name, $this->shortName . '::name');
        Assertion::maxLength($name, self::MAX_NAME_LENGTH, $this->shortName . '::name');

        $this->name = $name;
    }

    public function getAlias(): string
    {
        return $this->alias;
    }

    /**
     * @param string $alias
     *
     * @throws \Throwable
     */
    public function setAlias(string $alias): void
    {
        $alias = trim($alias);

        Assertion::notEmptyString($alias, $this->shortName . '::alias');
        Assertion::maxLength($alias, self::MAX_ALIAS_LENGTH, $this->shortName . '::alias');

        $this->alias = $alias;
    }

    public function getLevel(): int
    {
        return $this->level;
    }

    /**
     * @param int $level
     *
     * @throws \Throwable
     */
    public function setLevel(int $level): void
    {
        Assertion::min($level, self::MIN_LEVEL_VALUE, $this->shortName . '::level');
        Assertion::max($level, self::MAX_LEVEL_VALUE, $this->shortName . '::level');

        $this->level = $level;
    }

    public function getIconId(): int
    {
        return $this->iconId;
    }

    /**
     * @param int $iconId
     *
     * @throws \Throwable
     */
    public function setIconId(int $iconId): void
    {
        Assertion::positiveInt($iconId, $this->shortName . '::iconId');

        $this->iconId = $iconId;
    }

    public function isActivated(): bool
    {
        return $this->isActivated;
    }

    public function setActivated(bool $isActivated): void
    {
        $this->isActivated = $isActivated;
    }
}
